==> com.liferay.source.formatter-1.0.581-sources-commercial.jar: com/liferay/source/formatter/checkstyle/checks/NumberSuffixCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.source.formatter.checkstyle.checks;

import com.liferay.portal.kernel.util.StringUtil;

import com.puppycrawl.tools.checkstyle.api.DetailAST;
import com.puppycrawl.tools.checkstyle.api.TokenTypes;

/**
 * @author Hugo Huijser
 */
public class NumberSuffixCheck extends BaseCheck {

	@Override
	public int[] getDefaultTokens() {
		return new int[] {
			TokenTypes.NUM_DOUBLE, TokenTypes.NUM_FLOAT, TokenTypes.NUM_LONG
		};
	}

	@Override
	protected void doVisitToken(DetailAST detailAST) {
		if (detailAST.getType() == TokenTypes.NUM_DOUBLE) {
			_checkType(detailAST, "double", "d");
		}
		else if (detailAST.getType() == TokenTypes.NUM_FLOAT) {
			_checkType(detailAST, "float", "f");
		}
		else if (detailAST.getType() == TokenTypes.NUM_LONG) {
			_checkType(detailAST, "long", "l");
		}
	}

	private void _checkType(DetailAST detailAST, String type, String suffix) {
		String text = detailAST.getText();

		if (text.endsWith(suffix)) {
			log(
				detailAST.getLineNo(), _MSG_INCORRECT_SUFFIX,
				StringUtil.toUpperCase(suffix), type);
		}
	}

	private static final String _MSG_INCORRECT_SUFFIX = "suffix.incorrect";

}

==> com.liferay.source.formatter-1.0.793-sources-commercial.jar: com/liferay/source/formatter/checkstyle/checks/NumberSuffixCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.source.formatter.checkstyle.checks;

import com.liferay.portal.kernel.util.StringUtil;

import com.puppycrawl.tools.checkstyle.api.DetailAST;
import com.puppycrawl.tools.checkstyle.api.TokenTypes;

/**
 * @author Hugo Huijser
 */
public class NumberSuffixCheck extends BaseCheck {

	@Override
	public int[] getDefaultTokens() {
		return new int[] {
			TokenTypes.NUM_DOUBLE, TokenTypes.NUM_FLOAT, TokenTypes.NUM_LONG
		};
	}

	@Override
	protected void doVisitToken(DetailAST detailAST) {
		if (detailAST.getType() == TokenTypes.NUM_DOUBLE) {
			_checkType(detailAST, "double", "d");
		}
		else if (detailAST.getType() == TokenTypes.NUM_FLOAT) {
			_checkType(detailAST, "float", "f");
		}
		else if (detailAST.getType() == TokenTypes.NUM_LONG) {
			_checkType(detailAST, "long", "l");
		}
	}

	private void _checkType(DetailAST detailAST, String type, String suffix) {
		String text = detailAST.getText();

		if (text.endsWith(suffix)) {
			log(
				detailAST, _MSG_INCORRECT_SUFFIX,
				StringUtil.toUpperCase(suffix), type);
		}
	}

	private static final String _MSG_INCORRECT_SUFFIX = "suffix.incorrect";

}
